==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EntitlementValuesResponseLinksAnyOf.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntitlementValuesResponseLinksAnyOf
 */
@JsonPropertyOrder({ EntitlementValuesResponseLinksAnyOf.JSON_PROPERTY_BUNDLE,
        EntitlementValuesResponseLinksAnyOf.JSON_PROPERTY_ENTITLEMENTS })
@JsonTypeName("EntitlementValuesResponse__links_anyOf")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EntitlementValuesResponseLinksAnyOf implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BUNDLE = "bundle";
    private HrefObject bundle;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private HrefObject entitlements;

    public EntitlementValuesResponseLinksAnyOf() {
    }

    public EntitlementValuesResponseLinksAnyOf bundle(HrefObject bundle) {

        this.bundle = bundle;
        return this;
    }

    /**
     * Get bundle
     *
     * @return bundle
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BUNDLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getBundle() {
        return bundle;
    }

    @JsonProperty(JSON_PROPERTY_BUNDLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBundle(HrefObject bundle) {
        this.bundle = bundle;
    }

    public EntitlementValuesResponseLinksAnyOf entitlements(HrefObject entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(HrefObject entitlements) {
        this.entitlements = entitlements;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntitlementValuesResponseLinksAnyOf entitlementValuesResponseLinksAnyOf = (EntitlementValuesResponseLinksAnyOf) o;
        return Objects.equals(this.bundle, entitlementValuesResponseLinksAnyOf.bundle)
                && Objects.equals(this.entitlements, entitlementValuesResponseLinksAnyOf.entitlements);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(bundle, entitlements);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntitlementValuesResponseLinksAnyOf {\n");
        sb.append("    bundle: ").append(toIndentedString(bundle)).append("\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EntitlementValuesResponseLinksAnyOf.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntitlementValuesResponseLinksAnyOf
 */
@JsonPropertyOrder({ EntitlementValuesResponseLinksAnyOf.JSON_PROPERTY_BUNDLE,
        EntitlementValuesResponseLinksAnyOf.JSON_PROPERTY_ENTITLEMENTS })
@JsonTypeName("EntitlementValuesResponse__links_anyOf")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EntitlementValuesResponseLinksAnyOf implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BUNDLE = "bundle";
    private HrefObject bundle;

    public static final String JSON_PROPERTY_ENTITLEMENTS = "entitlements";
    private HrefObject entitlements;

    public EntitlementValuesResponseLinksAnyOf() {
    }

    public EntitlementValuesResponseLinksAnyOf bundle(HrefObject bundle) {

        this.bundle = bundle;
        return this;
    }

    /**
     * Get bundle
     *
     * @return bundle
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_BUNDLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getBundle() {
        return bundle;
    }

    @JsonProperty(JSON_PROPERTY_BUNDLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setBundle(HrefObject bundle) {
        this.bundle = bundle;
    }

    public EntitlementValuesResponseLinksAnyOf entitlements(HrefObject entitlements) {

        this.entitlements = entitlements;
        return this;
    }

    /**
     * Get entitlements
     *
     * @return entitlements
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getEntitlements() {
        return entitlements;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlements(HrefObject entitlements) {
        this.entitlements = entitlements;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntitlementValuesResponseLinksAnyOf entitlementValuesResponseLinksAnyOf = (EntitlementValuesResponseLinksAnyOf) o;
        return Objects.equals(this.bundle, entitlementValuesResponseLinksAnyOf.bundle)
                && Objects.equals(this.entitlements, entitlementValuesResponseLinksAnyOf.entitlements);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(bundle, entitlements);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntitlementValuesResponseLinksAnyOf {\n");
        sb.append("    bundle: ").append(toIndentedString(bundle)).append("\n");
        sb.append("    entitlements: ").append(toIndentedString(entitlements)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
